@@ -78,8 +78,8 @@ OWM_URL = "https://api.openweathermap.org/data/2.5/weather?lat={lat:.4f}&lon={lo
 
 class NowcastPublisher(Publisher):
 
-    def __init__(self, addr, locations, token):
-        super().__init__(addr, b"weather", None, 300)
+    def __init__(self, addr, locations, token, frequency):
+        super().__init__(addr, b"weather", None, frequency)
 
         self.locations = [{
             'name': a['name'],
@@ -187,6 +187,7 @@ def main(config):
     addr = config['addr']
     locations = config['locations']
     token = config['owm_token']
+    freq = config['frequency']
 
-    with NowcastPublisher(addr, locations, token) as publisher:
+    with NowcastPublisher(addr, locations, token, freq) as publisher:
         publisher.loop()
