@@ -111,7 +111,7 @@ def proxy_buffering(frontend_addr, backend_addr, capture_addr=None):
         cache[item[0]].append(item)
 
     for topic in cache.keys():
-        csize  = len(cache[item])
+        csize  = len(cache[topic])
         if csize > 0:
             logger.warning(f"{topic} - {csize} cached items loaded")
 
@@ -145,14 +145,6 @@ def proxy_buffering(frontend_addr, backend_addr, capture_addr=None):
             msg = frontend.recv_multipart()
             topic = msg[0]
 
-            j = json.loads(msg[1])
-            try:
-                if topic != b'eink':
-                    if j['tags']['name'] == "study":
-                        logger.warning(json.dumps(j, indent=2))
-            except KeyError:
-                logger.warning(msg)
-
             #frontend.send_multipart([b"\x00rain"])
 
             if topic not in lvc:
