@@ -16,8 +16,14 @@ def get_recent(statefile, grace=10):
     for name, data in state.items():
         okdiff = timedelta(minutes=grace, seconds=int(data['tags'].get('frequency', 240)))
         dt = datetime.fromisoformat(data['time'])
+        print(repr(data['time']))
+        print(repr(dt))
+        print(repr(now))
+
         try:
             diff = now - dt
+            print(repr(diff))
+            print("====")
             is_recent = diff < okdiff
         except TypeError as e:
             if "offset-naive and offset-aware" in e.args[0]:
