@@ -228,7 +228,11 @@ class ArduinoSensor(object):
 
         ser_timeout = float(self.ard_loop_timeout) # seconds
         logger.debug(f"serial timeout: {ser_timeout}s")
-        self.ser = serial.Serial(device, baudrate, timeout=ser_timeout)
+
+        try:
+            self.ser = serial.Serial(device, baudrate, timeout=ser_timeout)
+        except serial.SerialException as e:
+            raise NoSensorDetectedError(e)
 
 
     def as_dict(self):
